pyxmpp2.exceptions.ResourceConstraintProtocolError

Package pyxmpp2 :: Module exceptions :: Class ResourceConstraintProtocolError |
[hide private]

# Class ResourceConstraintProtocolError

Raised when stanza requests a feature which is not (yet) implemented.

Instance Methods | [hide private]
__init__(self, message) x.__init__(...) initializes x; see help(type(x)) for signature |
Inherited from `ProtocolError`: `__repr__`, `__unicode__`, `log_ignored`, `log_reported` Inherited from `exceptions.StandardError`: `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__setattr__`, `__setstate__`, `__str__` Inherited from `object`: `__format__`, `__hash__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `ProtocolError`: `logger_ignored`, `logger_reported`

Properties | [hide private]
Inherited from `ProtocolError`: `message`, `xmpp_name` Inherited from `exceptions.BaseException`: `args` Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, message) (Constructor) |
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)